==> hinemos_manager-4.0.1_rhel6_32.tar.gz: Hinemos_Manager-4.0.1_rhel6_32/hinemos/lib/cr/rpminstall.sh <==
#!/bin/sh

# Copyright (C) since 2006 NTT DATA Corporation
# 
# This program is free software; you can redistribute it and/or
# Modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation, version 2.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details

# bash configuration
RPM_PROC="/bin/rpm -Uvh"
FTP_PROC="/usr/kerberos/bin/ftp"
FTP_HOST=%%FTP_HOST%%
FTP_USER="hinemos"
FTP_PASSWD="hinemos"
RM_PROC="/bin/rm -f"

# RPM file name
rpmfile=${1##/*/}
# RPM file remote path
remotepath=${1%/*}

echo $rpmfile
echo $remotepath


##
## The rpm file is forwarded from the server in the local. 
##
if [ -f ${FTP_PROC} ]; then
    echo "FTP Command "$FTP_PROC" is installed."
else
    echo "FTP Command "$FTP_PROC" is not installed. Please install RPM package."
    exit -1
fi

expect -c "
    set timeout 300
    spawn $FTP_PROC $FTP_HOST
    expect Name*:
    send $FTP_USER\r
    expect Password:
    send $FTP_PASSWD\r
    expect {
	successful.	{}
	failed.		{exit 1}
	timeout		{exit 1}
    }
    send \"cd $remotepath\r\"
    expect >
    send \"get $rpmfile\r\"
    expect {
	complete.		{}	
	Failed		{exit 1}
	timeout		{exit 1}
    }
    expect >
    send quit\r
    expect eof
"
if [ $? -ne 0 ] ; then
    echo 'File transfer error' 1>&2
    exit 10
fi

##
## rpm command
##
echo "$RPM_PROC $rpmfile"
$RPM_PROC $rpmfile
RETVAL=$?


##
## delete rpm file
##
echo "$RM_PROC $rpmfile"
$RM_PROC $rpmfile

echo "exit $RETVAL"
if [ $RETVAL -ne 0 ] ; then
    exit 20
fi

exit

==> hinemos_manager-4.1.1_rhel6_32.tar.gz: Hinemos_Manager-4.1.1_rhel6_32/hinemos/lib/cr/rpminstall.sh <==
#!/bin/sh

# Copyright (C) since 2006 NTT DATA Corporation
# 
# This program is free software; you can redistribute it and/or
# Modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation, version 2.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details

# bash configuration
RPM_PROC="/bin/rpm -Uvh"
FTP_PROC="/usr/bin/ftp"
FTP_HOST=%%FTP_HOST%%
FTP_USER="hinemos"
FTP_PASSWD="hinemos"
RM_PROC="/bin/rm -f"

# RPM file name
rpmfile=${1##/*/}
# RPM file remote path
remotepath=${1%/*}

echo $rpmfile
echo $remotepath


##
## The rpm file is forwarded from the server in the local. 
##
if [ -f ${FTP_PROC} ]; then
    echo "FTP Command "$FTP_PROC" is installed."
else
    echo "FTP Command "$FTP_PROC" is not installed. Please install RPM package."
    exit -1
fi

expect -c "
    set timeout 300
    spawn $FTP_PROC $FTP_HOST
    expect Name*:
    send $FTP_USER\r
    expect Password:
    send $FTP_PASSWD\r
    expect {
	successful.	{}
	failed.		{exit 1}
	timeout		{exit 1}
    }
    send \"cd $remotepath\r\"
    expect >
    send \"get $rpmfile\r\"
    expect {
	complete.		{}	
	Failed		{exit 1}
	timeout		{exit 1}
    }
    expect >
    send quit\r
    expect eof
"
if [ $? -ne 0 ] ; then
    echo 'File transfer error' 1>&2
    exit 10
fi

##
## rpm command
##
echo "$RPM_PROC $rpmfile"
$RPM_PROC $rpmfile
RETVAL=$?


##
## delete rpm file
##
echo "$RM_PROC $rpmfile"
$RM_PROC $rpmfile

echo "exit $RETVAL"
if [ $RETVAL -ne 0 ] ; then
    exit 20
fi

exit
